@@ -375,7 +375,8 @@ OpenEXROutput::open(const std::string& name, const ImageSpec& userspec,
         m_nmiplevels = 1;
         m_miplevel   = 0;
         m_headers.resize(1);
-        copy_and_check_spec(userspec, m_spec);
+        if (!copy_and_check_spec(userspec, m_spec))
+            return false;
         sanity_check_channelnames();
         const ParamValue* param = m_spec.find_attribute("oiio:ioproxy",
                                                         TypeDesc::PTR);
@@ -960,6 +961,14 @@ OpenEXROutput::put_parameter(const std::string& name, TypeDesc type,
                 header.compression() = Imf::DWAA_COMPRESSION;
             else if (Strutil::iequals(str, "dwab"))
                 header.compression() = Imf::DWAB_COMPRESSION;
+#ifdef IMF_HTJ2K256_COMPRESSION
+            else if (Strutil::iequals(str, "htj2k256"))
+                header.compression() = Imf::HTJ2K256_COMPRESSION;
+#endif
+#ifdef IMF_HTJ2K32_COMPRESSION
+            else if (Strutil::iequals(str, "htj2k32"))
+                header.compression() = Imf::HTJ2K32_COMPRESSION;
+#endif
         }
         return true;
     }
@@ -1317,7 +1326,7 @@ OpenEXROutput::sanity_check_channelnames()
             if (m_spec.channelnames[c].empty()
                 || m_spec.channelnames[c] == m_spec.channelnames[i]) {
                 // Duplicate or missing channel name! We don't want
-                // libIlmImf to drop the channel (as it will do for
+                // libOpenEXR to drop the channel (as it will do for
                 // duplicates), so rename it and hope for the best.
                 m_spec.channelnames[c] = Strutil::fmt::format("channel{}", c);
                 break;
@@ -1380,7 +1389,8 @@ OpenEXROutput::write_scanline(int y, int z, TypeDesc format, const void* data,
     // where the address of the "virtual framebuffer" for the whole
     // image.
     imagesize_t scanlinebytes = m_spec.scanline_bytes(native);
-    char* buf = (char*)data - m_spec.x * pixel_bytes - y * scanlinebytes;
+    char* buf                 = (char*)data - ptrdiff_t(m_spec.x * pixel_bytes)
+                - ptrdiff_t(y * scanlinebytes);
 
     try {
         Imf::FrameBuffer frameBuffer;
@@ -1643,7 +1653,8 @@ OpenEXROutput::write_tiles(int xbegin, int xend, int ybegin, int yend,
         data = &padded[0];
     }
 
-    char* buf = (char*)data - xbegin * pixelbytes - ybegin * widthbytes;
+    char* buf = (char*)data - ptrdiff_t(xbegin * pixelbytes)
+                - ptrdiff_t(ybegin * widthbytes);
 
     try {
         Imf::FrameBuffer frameBuffer;
